Validation checks used in samplers — imbalanced-ensemble 0.1.0 documentation

# Validation checks used in samplers

The `imbalanced_ensemble.utils` module includes various utilities.

`check_neighbors_object`(nn_name, nn_object[, …]) | Check the objects is consistent to be a NN.
`check_sampling_strategy`(sampling_strategy, …) | Sampling target validation for samplers.
`check_target_type`(y[, indicate_one_vs_all]) | Check the target types to be conform to the current samplers.